% Calculating Reynolds number with Picard iteration
function [Re_clean, v_clean, Re_part, v_part, Re_cont, v_cont] = FPI()

global d_b Nz mu_l rho_G rho_l D_l g 
%% Start out iteration loop

delta_rho = rho_l - rho_G; % kg/m^3

E0 = zeros(Nz,1);       % Eotvos number

% Clean
v_clean  = zeros(Nz,1);
Re_clean = zeros(Nz,1);
CD_clean = zeros(Nz,1);
% Partly contaminated
v_part   = zeros(Nz,1);
Re_part  = zeros(Nz,1);
CD_part  = zeros(Nz,1);
% Contaminated
v_cont   = zeros(Nz,1);
Re_cont  = zeros(Nz,1);
CD_cont  = zeros(Nz,1);

    
% Initial guess
v_clean  = 0.4;
v_part   = 0.4;
v_cont   = 0.4;
error_clean = 3000;
error_part  = 3000;
error_cont  = 3000;

while error_clean > 1e-8 || error_part > 1e-8 || error_cont > 1e-8

    E0       = delta_rho.*g.*(d_b^2)./0.076;

    Re_clean = rho_l*v_clean*d_b/mu_l;
    CD_clean = max(min((16./Re_clean).*(1 + 0.15*...
                     Re_clean.^(0.687)), 48./Re_clean),...
                     (8/3).*E0./(E0+4));
    v_clean_new = ((4/3)*g*d_b.*delta_rho./(CD_clean*rho_l)).^0.5;
    error_clean = abs((v_clean_new-v_clean)./v_clean_new);
    v_clean     = v_clean_new;

    Re_part     = rho_l*v_part.*d_b./mu_l;
    CD_part     = max(min((24./Re_part).*(1 + 0.15.*...
                    Re_part.^(0.687)),72./Re_part),...
                    (8/3)*E0./(E0+4));
    v_part_new  = ((4/3)*g*d_b*delta_rho./(CD_part.*rho_l)).^0.5;
    error_part  = abs((v_part_new-v_part)./v_part_new);
    v_part      = v_part_new;

    Re_cont     = rho_l*v_cont.*d_b./mu_l;
    CD_cont     = max((24/Re_cont).*(1 + 0.15*...
                    Re_cont.^(0.687)),(8/3)*E0./(E0+4));
    v_cont_new  = ((4/3)*g*d_b*delta_rho./(CD_cont*rho_l)).^0.5;
    error_cont  = abs((v_cont_new-v_cont)./v_cont_new);
    v_cont      = v_cont_new; 
end     

                
                
                
                
                
                
                
                

